@@ -22,6 +22,9 @@ import json
 import argparse
 import boto3
 
+import time
+import hashlib
+
 def set_arguments(servicetype):
     parser = argparse.ArgumentParser(description="Ubirch " + servicetype + " anchoring service")
 
